@@ -8,6 +8,13 @@ POK = Instruction(
         ]
     )
 
+LON = Instruction(
+        'LON',
+        0x01,
+        [
+        ]
+    )
+
 DEL = Instruction(
         'DEL',
         0x02,
@@ -16,6 +23,13 @@ DEL = Instruction(
         ]
     )
 
+LOF = Instruction(
+        'LOF',
+        0x03,
+        [
+        ]
+    )
+
 JMP = Instruction(
         'JMP',
         0x04,
@@ -278,9 +292,71 @@ MVL = Instruction(
         ]
     )
 
+JEL = Instruction(
+        'JEL',
+        0x20,
+        [
+            Argument('target', PTR),
+            Argument('check', PTR),
+            Argument('value', LONG),
+            Argument('saveip', BYTE),
+        ]
+    )
+
+JLL = Instruction(
+        'JLL',
+        0x21,
+        [
+            Argument('target', PTR),
+            Argument('check', PTR),
+            Argument('value', LONG),
+            Argument('saveip', BYTE),
+        ]
+    )
+
+JGL: = Instruction(
+        'JGL:',
+        0x22,
+        [
+            Argument('target', PTR),
+            Argument('check', PTR),
+            Argument('value', LONG),
+            Argument('saveip', BYTE),
+        ]
+    )
+
+PKB = Instruction(
+        'PKB',
+        0x23,
+        [
+            Argument('value', BYTE),
+            Argument('location', PTR),
+        ]
+    )
+
+PKI = Instruction(
+        'PKI',
+        0x24,
+        [
+            Argument('value', INT),
+            Argument('location', PTR),
+        ]
+    )
+
+PKL = Instruction(
+        'PKL',
+        0x25,
+        [
+            Argument('value', LONG),
+            Argument('location', PTR),
+        ]
+    )
+
 instructions = {
         0x00: POK,
+        0x01: LON,
         0x02: DEL,
+        0x03: LOF,
         0x04: JMP,
         0x05: ADB,
         0x06: ADI,
@@ -309,4 +385,10 @@ instructions = {
         0x1D: MVB,
         0x1E: MVI,
         0x1F: MVL,
+        0x20: JEL,
+        0x21: JLL,
+        0x22: JGL:,
+        0x23: PKB,
+        0x24: PKI,
+        0x25: PKL,
 }
